"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from sdk import utils

class E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329Status(str, Enum):
    ACTIVE = 'Active'
    PAUSED = 'Paused'
    DISABLED = 'Disabled'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329:
    effective_date: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('effectiveDate') }})
    group_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('groupNumber') }})
    member_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('memberNumber') }})
    status: E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329Status = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    

