"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from sdk import utils
from typing import Any


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class A71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc:
    deduction_ids: Any = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('deductionIds') }})
    

